summaryrefslogtreecommitdiffstats
path: root/khotkeys/shared/voices.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:33:34 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:33:34 +0000
commitc663b6440964f6ac48027143ac9e63298991f9d0 (patch)
tree6d8b0c5a5f9db1ee16acf98b1397cea9126b281d /khotkeys/shared/voices.h
parenta061f7191beebb0e4a3b0c0a7c534ec5f22f2dc7 (diff)
downloadtdebase-c663b6440964f6ac48027143ac9e63298991f9d0.tar.gz
tdebase-c663b6440964f6ac48027143ac9e63298991f9d0.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1157639 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'khotkeys/shared/voices.h')
-rw-r--r--khotkeys/shared/voices.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/khotkeys/shared/voices.h b/khotkeys/shared/voices.h
index b0193e7c2..89329ba5d 100644
--- a/khotkeys/shared/voices.h
+++ b/khotkeys/shared/voices.h
@@ -11,7 +11,7 @@
#ifndef VOICES_H_
#define VOICES_H_
-#include <qwidget.h>
+#include <tqwidget.h>
#include <kshortcut.h>
class Sound;
@@ -32,7 +32,7 @@ class KDE_EXPORT Voice : public QObject
{
Q_OBJECT
public:
- Voice( bool enabled_P, QObject* parent_P );
+ Voice( bool enabled_P, TQObject* parent_P );
virtual ~Voice();
void enable( bool enable_P );
@@ -43,12 +43,12 @@ class KDE_EXPORT Voice : public QObject
void set_shortcut( const KShortcut &k);
/**
* return QString::null is a new signature is far enough from others signature
* otherwise, return the stringn which match.
*/
- QString isNewSoundFarEnough(const VoiceSignature& s, const QString& currentTrigger);
+ TQString isNewSoundFarEnough(const VoiceSignature& s, const TQString& currentTrigger);
- bool doesVoiceCodeExists(const QString &s);
+ bool doesVoiceCodeExists(const TQString &s);
public slots:
void record_start();
@@ -60,19 +60,19 @@ class KDE_EXPORT Voice : public QObject
void slot_timeout();
signals:
- void handle_voice( const QString &voice );
+ void handle_voice( const TQString &voice );
private:
bool _enabled;
bool _recording;
- QValueList<Voice_trigger *> _references;
+ TQValueList<Voice_trigger *> _references;
SoundRecorder *_recorder;
KShortcut _shortcut;
KGlobalAccel *_kga;
- QTimer *_timer;
+ TQTimer *_timer;
};
@@ -43,12 +43,12 @@ class KDE_EXPORT Voice : public QObject
void set_shortcut( const KShortcut &k);
/**
- * return QString::null is a new signature is far enough from others signature
+ * return TQString::null is a new signature is far enough from others signature
* otherwise, return the stringn which match.
*/